==> digikam-4.7.0.tar.bz2: digikam-4.7.0/extra/kipi-plugins/rajceexport/kipiplugin_rajceexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Rajce.net Exporter
Name=Rajce.net Exporter
Name[bg]=Изнасяне към Rajce.net
Name[bs]=Rajce.net izvoznik
Name[ca]=Exportador a Rajce.net
Name[ca@valencia]=Exportador a Rajce.net
Name[cs]=Exportér Rajce.net
Name[da]=Rajce.net-eksportør
Name[de]=Rajce.net-Export
Name[el]=Εξαγωγέας Rajce.net
Name[en_GB]=Rajce.net Exporter
Name[es]=Exportar a rajce.net
Name[et]=Rajce.net-i eksportija
Name[fi]=Rajce.net-vienti
Name[fr]=Outil d'exportation « Rajce.net »
Name[ga]=Easpórtálaí Rajce.net
Name[gl]=Exportador a Rajce.net
Name[hu]=Rajce.net exportáló
Name[is]=Rajce.net útflutningstól
Name[it]=Esportatore a Rajce.net
Name[km]=កម្មវិធី​នាំចេញ Rajce.net​
Name[nb]=Rajce.net eksporterer
Name[nl]=Exportprogramma van Rajce.net
Name[pl]=Eksporter Rajce.net
Name[pt]=Exportação para o Rajce.net
Name[pt_BR]=Exportar para o Rajce.net
Name[ro]=Exportator Rajce.net
Name[ru]=Экспорт в Rajce.net
Name[sk]=Rajce.net exportovač
Name[sl]=Izvoz v Rajce.net
Name[sv]=Export till Rajce.net
Name[tr]=Rajce.net Aktarıcısı
Name[uk]=Експорт до Rajce.net
Name[x-test]=xxRajce.net Exporterxx
Name[zh_TW]=Rajce.net 匯出器
Comment=A tool to export images to a remote rajce.net service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга rajce.net
Comment[bs]=Alat za izvoz slika na udaljeni rajce.net web servis
Comment[ca]=Una eina per exportar imatges al servei web remot rajce.net
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot rajce.net
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby rajce.net
Comment[da]=Et værktøj til at eksportere billeder til en ekstern rajce.net-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten rajce.net-Service zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού rajce.net
Comment[en_GB]=A tool to export images to a remote rajce.net service
Comment[es]=Una herramienta para exportar imágenes al servicio remoto de rajce.net
Comment[et]=Tööriist piltide eksportimiseks rajce.net-i veebiteenusesse
Comment[fi]=Kuvien vienti rajce.net-verkkopalveluun
Comment[fr]=Un outil d'exportation d'images vers le service en ligne « rejce.net »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís chianda rajce.net
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web rajce.net remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli rajce.net szolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Rajce.net vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto rajce.net
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​ rajce.net ពី​ចម្ងាយ​
Comment[nb]=Et verktøy for å eksportere bilder til en fjern rajce.net-tjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een rajce.net-service te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej rajce.net
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Rajce.net
Comment[pt_BR]=Ferramenta para exportar imagens para o rajce.net
Comment[ro]=O unealtă de exportat imagini pe serviciul web rajce.net
Comment[ru]=Инструмент для экспорта изображений в веб-службу Rajce.net
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu rajce.net
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev rajce.net
Comment[sv]=Ett verktyg för att exportera bilder till en rajce.net fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir rajce.net hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби rajce.net
Comment[x-test]=xxA tool to export images to a remote rajce.net servicexx
Comment[zh_TW]=匯出影像到遠端 rajce.net 網頁服務的工具
Type=Service
Icon=kipi-rajce
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_rajceexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Lukas Krejci, krejci.l at centrum dot cz

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/rajceexport/kipiplugin_rajceexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Rajce.net Exporter
Name=Rajce.net Exporter
Name[bg]=Изнасяне към Rajce.net
Name[bs]=Rajce.net izvoznik
Name[ca]=Exportador a Rajce.net
Name[ca@valencia]=Exportador a Rajce.net
Name[cs]=Exportér Rajce.net
Name[da]=Rajce.net-eksportør
Name[de]=Rajce.net-Export
Name[el]=Εξαγωγέας Rajce.net
Name[en_GB]=Rajce.net Exporter
Name[es]=Exportar a rajce.net
Name[et]=Rajce.net-i eksportija
Name[fi]=Rajce.net-vienti
Name[fr]=Outil d'export « Rajce.net »
Name[ga]=Easpórtálaí Rajce.net
Name[gl]=Exportador a Rajce.net
Name[hu]=Rajce.net exportáló
Name[is]=Rajce.net útflutningstól
Name[it]=Esportatore a Rajce.net
Name[km]=កម្មវិធី​នាំចេញ Rajce.net​
Name[nb]=Rajce.net eksporterer
Name[nl]=Exportprogramma van Rajce.net
Name[pl]=Eksporter Rajce.net
Name[pt]=Exportação para o Rajce.net
Name[pt_BR]=Exportar para o Rajce.net
Name[ro]=Exportator Rajce.net
Name[ru]=Экспорт в Rajce.net
Name[sk]=Rajce.net exportovač
Name[sl]=Izvoz v Rajce.net
Name[sv]=Export till Rajce.net
Name[tr]=Rajce.net Aktarıcısı
Name[uk]=Експорт до Rajce.net
Name[x-test]=xxRajce.net Exporterxx
Name[zh_TW]=Rajce.net 匯出器
Comment=A tool to export images to a remote rajce.net service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга rajce.net
Comment[bs]=Alat za izvoz slika na udaljeni rajce.net web servis
Comment[ca]=Una eina per exportar imatges al servei web remot rajce.net
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot rajce.net
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby rajce.net
Comment[da]=Et værktøj til at eksportere billeder til en ekstern rajce.net-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten rajce.net-Service zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού rajce.net
Comment[en_GB]=A tool to export images to a remote rajce.net service
Comment[es]=Una herramienta para exportar imágenes al servicio remoto de rajce.net
Comment[et]=Tööriist piltide eksportimiseks rajce.net-i veebiteenusesse
Comment[fi]=Kuvien vienti rajce.net-verkkopalveluun
Comment[fr]=Un outil d'export d'images vers le service en ligne « rejce.net »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís chianda rajce.net
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web rajce.net remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli rajce.net szolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Rajce.net vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto rajce.net
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​ rajce.net ពី​ចម្ងាយ​
Comment[nb]=Et verktøy for å eksportere bilder til en fjern rajce.net-tjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een rajce.net-service te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej rajce.net
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Rajce.net
Comment[pt_BR]=Ferramenta para exportar imagens para o rajce.net
Comment[ro]=O unealtă de exportat imagini pe serviciul web rajce.net
Comment[ru]=Инструмент для экспорта изображений в веб-службу Rajce.net
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu rajce.net
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev rajce.net
Comment[sv]=Ett verktyg för att exportera bilder till en rajce.net fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir rajce.net hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби rajce.net
Comment[x-test]=xxA tool to export images to a remote rajce.net servicexx
Comment[zh_TW]=匯出影像到遠端 rajce.net 網頁服務的工具
Type=Service
Icon=kipi-rajce
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_rajceexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Lukas Krejci, krejci.l at centrum dot cz
